@@ -511,6 +511,7 @@ int 	pass = 0, fail = 0;
 		CHECK;
 
 	if (config.alt_screen != -1) {
+		XDeviceKeyEvent *kev;
 		altroot = RootWindow(display, config.alt_screen);
 		trace("Testing with root of alternate screen as source (0x%x) and PointerRoot.",
 				(unsigned)altroot);
@@ -523,22 +524,25 @@ int 	pass = 0, fail = 0;
 		if (!getevent(display, &ev)) {
 			report("No event received.");
 			FAIL;
-		} else if (ev.type != dkp && ev.type != dkr) {
-			report("First event was of unexpected type: %s.", eventname(ev.type));
-			FAIL;
-		} else if (ev.xkey.window != altroot) {
-			report("First event had unexpected window: 0x%x instead of focus (altroot) 0x%x.",
-				(unsigned)ev.xkey.window, (unsigned)altroot);
-			FAIL;
-		} else if (!ev.xkey.same_screen) {
-			report("same_screen unexpectedly False.");
-			FAIL;
-		} else if (ev.xkey.root != altroot) {
-			report("First event had unexpected root window: 0x%x instead of 0x%x.",
-				(unsigned)ev.xkey.root, (unsigned)altroot);
-			FAIL;
-		} else
-			CHECK;
+		} else {
+			kev = (XDeviceKeyEvent*)&ev;
+			if (ev.type != dkp && ev.type != dkr) {
+				report("First event was of unexpected type: %s.", eventname(ev.type));
+				FAIL;
+			} else if (kev->window != altroot) {
+				report("First event had unexpected window: 0x%x instead of focus (altroot) 0x%x.",
+						(unsigned)ev.xkey.window, (unsigned)altroot);
+				FAIL;
+			} else if (!kev->same_screen) {
+				report("same_screen unexpectedly False.");
+				FAIL;
+			} else if (kev->root != altroot) {
+				report("First event had unexpected root window: 0x%x instead of 0x%x.",
+						(unsigned)ev.xkey.root, (unsigned)altroot);
+				FAIL;
+			} else
+				CHECK;
+		}
 		CHECKPASS(4);
 	} else {
 		report("Tested as far as possible with just one screen.");
@@ -559,6 +563,7 @@ XEvent	ev;
 int	n, sav_revert;
 int	dkp, dkr;
 XEventClass classes[2];
+XEventClass none_class;
 int 	pass = 0, fail = 0;
 
  	report_purpose(5);
@@ -586,6 +591,9 @@ int 	pass = 0, fail = 0;
 	DeviceKeyRelease(device, dkr, classes[1]);
 	win = defwin(display);
 	XSelectExtensionEvent(display, win, classes, 2);
+	/* previous test selected for events on the root window */
+	NoExtensionEvent(device, 0, none_class);
+	XSelectExtensionEvent(display, DRW(display), &none_class, 1);
 
 	focus = FollowKeyboard;
 	startcall(display);
