@@ -237,7 +237,7 @@ int		v;
 XIconSize	sizelist[5];
 int		count = 5;
 int		rcount;
-XIconSize	*sp = (XIconSize *) NULL, *sref;
+XIconSize	*sp = NULL, *sref;
 int 	pass = 0, fail = 0;
 
  	report_purpose(1);
