@@ -240,15 +240,17 @@ SOFTWARE.
 	fail++; \
 	} else pass++;
 
+#ifdef INPUTEXTENSION
+int check_ext_event(XEvent*, XEvent*);
+#endif
+
 /*
  * Compare two events.
  * Returns the number of fields that compared false.
  * On error (eg. no such event type) returns -1.
  */
 int
-checkevent(good, ev)
-XEvent *good;
-XEvent *ev;
+checkevent(XEvent *good, XEvent *ev)
 {
 int 	i;
 int 	fail;
@@ -661,8 +663,8 @@ char	tempstr[50];
 }
 
 #ifdef INPUTEXTENSION
-check_ext_event(good,ev)
-XEvent *good, *ev;
+int
+check_ext_event(XEvent *good, XEvent *ev)
 {
 int i;
 int 	fail;
